pub const fn repeat_n<T: Clone>(item: T, count: Size) -> RepeatN<T>Expand description
Creates RepeatN<T> non-empty iterator that repeats the given item the given number of times.
pub const fn repeat_n<T: Clone>(item: T, count: Size) -> RepeatN<T>Creates RepeatN<T> non-empty iterator that repeats the given item the given number of times.